@@ -1,7 +1,7 @@
 package Perinci::Sub::To::FuncBase;
 
-our $DATE = '2017-07-03'; # DATE
-our $VERSION = '0.85'; # VERSION
+our $DATE = '2017-08-12'; # DATE
+our $VERSION = '0.860'; # VERSION
 
 use 5.010;
 use Log::ger;
@@ -118,7 +118,9 @@ sub gen_doc_section_description {
     my $rimeta = rimeta($self->meta);
     my $dres   = $self->{_doc_res};
 
-    $dres->{description} = $rimeta->langprop("description");
+    # XXX proper alt. search
+    $dres->{description} = $self->{meta}{'description.alt.env.perl'} //
+        $rimeta->langprop("description");
 }
 
 sub gen_doc_section_arguments {
@@ -226,7 +228,7 @@ Perinci::Sub::To::FuncBase - Base class for Perinci::Sub::To::* function documen
 
 =head1 VERSION
 
-This document describes version 0.85 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2017-07-03.
+This document describes version 0.860 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2017-08-12.
 
 =for Pod::Coverage .+
 
